@@ -110,11 +110,13 @@ importSAQN <- function(site = "gla4", year = 2009, pollutant = "all") {
       fileName <- paste("http://www.scottishairquality.co.uk/openair/R_data/", x, ".RData", sep = "")
       con <- url(fileName)
       load(con, envir = .GlobalEnv)
-      close(con)
       x
     },
     error = function(ex) {
       cat(x, "does not exist - ignoring that one.\n")
+    },
+    finally = {
+        close(con)
     }
     )
   }
@@ -128,7 +130,7 @@ importSAQN <- function(site = "gla4", year = 2009, pollutant = "all") {
   ## note unlist will drop NULLs from non-existant sites/years
   mylist <- lapply(theObjs, get)
 
-  thedata <- do.call(bind_rows, mylist)
+  thedata <- suppressWarnings(do.call(bind_rows, mylist))
   if (is.null(thedata) || nrow(thedata) == 0) stop("No data to import - check site codes and year.", call. = FALSE)
 
   thedata$site <- factor(thedata$site, levels = unique(thedata$site))
